#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.

"""Class to use pyscf program to access quantum chemistry data."""

import numpy
from functools import reduce
from pyscf import ao2mo
from pyscf import scf
from openfermion.hamiltonians import MolecularData


class PyscfMolecularData(MolecularData):

    """A derived class from openfermion.hamiltonians.MolecularData. This class
    is created to store the PySCF method objects as well as molecule data from
    a fixed basis set at a fixed geometry that is obtained from PySCF
    electronic structure packages. This class provides an interface to access
    the PySCF Hartree-Fock, MP, CI, Coupled-Cluster methods and their energies,
    density matrices and wavefunctions.

    Attributes:
        _pyscf_data(dict): To store PySCF method objects temporarily.
    """
    def __init__(self, geometry=None, basis=None, multiplicity=None,
                 charge=0, description="", filename="", data_directory=None):
        MolecularData.__init__(self, geometry, basis, multiplicity,
                               charge, description, filename, data_directory)
        self._pyscf_data = {}

    @property
    def canonical_orbitals(self):
        """Hartree-Fock canonical orbital coefficients (represented on AO
        basis).
        """
        if self._canonical_orbitals is None:
            scf = self._pyscf_data.get('scf', None)
            self._canonical_orbitals = scf.mo_coeff
        return self._canonical_orbitals

    @property
    def overlap_integrals(self):
        """Overlap integrals for AO basis."""
        if self._overlap_integrals is None:
            scf = self._pyscf_data.get('scf', None)
            self._overlap_integrals = scf.get_ovlp()
        return self._overlap_integrals

    @property
    def one_body_integrals(self):
        """A 2D array for one-body Hamiltonian (H_core) in the MO
        representation."""
        if self._one_body_integrals is None:
            scf = self._pyscf_data.get('scf', None)
            mo = self.canonical_orbitals
            h_core = scf.get_hcore()
            self._one_body_integrals = reduce(numpy.dot, (mo.T, h_core, mo))
        return self._one_body_integrals

    @property
    def two_body_integrals(self):
        """A 4-dimension array for electron repulsion integrals in the MO
        representation.  The integrals are computed as
        h[p,q,r,s]=\int \phi_p(x)* \phi_q(y)* V_{elec-elec} \phi_r(y) \phi_s(x) dxdy
        """
        if self._two_body_integrals is None:
            mol = self._pyscf_data.get('mol', None)
            mo = self.canonical_orbitals
            n_orbitals = mo.shape[1]

            eri = ao2mo.kernel(mol, mo)
            eri = ao2mo.restore(1, # no permutation symmetry
                                eri, n_orbitals)
            # See PQRS convention in OpenFermion.hamiltonians.molecular_data
            # h[p,q,r,s] = (ps|qr) = pyscf_eri[p,s,q,r]
            self._two_body_integrals = numpy.asarray(
                eri.transpose(0, 2, 3, 1), order='C')
        return self._two_body_integrals

    @property
    def cisd_one_rdm(self):
        r"""A 2-dimension array for CISD one-particle density matrix in the MO
        representation.  d[p,q] = < a^\dagger_p a_q >
        """
        if self._cisd_one_rdm is None:
            cisd = self._pyscf_data.get('cisd', None)
            if cisd is None:
                return None

            mf = self._pyscf_data.get('scf', None)
            if isinstance(mf, scf.uhf.UHF):
                raise ValueError('Spin trace for UCISD density matrix.')

            rdm1 = cisd.make_rdm1()
            if isinstance(mf, scf.rohf.ROHF):
                rdm1 = rdm1[0] + rdm1[1]

# pyscf one_rdm is computed as dm1[p,q] = <a^\dagger_q a_p>
            self._cisd_one_rdm = rdm1.T
        return self._cisd_one_rdm

    @property
    def cisd_two_rdm(self):
        r"""A 4-dimension array for CISD two-particle density matrix in the MO
        representation.  D[p,q,r,s] = < a^\dagger_p a^\dagger_q a_r a_s >
        """
        if self._cisd_two_rdm is None:
            cisd = self._pyscf_data.get('cisd', None)
            if cisd is None:
                return None

            mf = self._pyscf_data.get('scf', None)
            if isinstance(mf, scf.uhf.UHF):
                raise ValueError('Spin trace for UCISD density matrix.')

            rdm2 = cisd.make_rdm2()
            if isinstance(mf, scf.rohf.ROHF):
                aa, ab, bb = rdm2
                rdm2 = aa + bb + ab + ab.transpose(2, 3, 0, 1)

# pyscf.ci.cisd.make_rdm2 convention
#       dm2[p,s,q,r] = <a^\dagger_p a^\dagger_q a_r a_s>.
# the two_body_tensor in openfermion.ops._interaction_rdm.InteractionRDM
#       tbt[p,q,r,s] = <a^\dagger_p a^\dagger_q a_r a_s>.
            self._cisd_two_rdm = rdm2.transpose(0, 2, 3, 1)
        return self._cisd_two_rdm

    @property
    def ccsd_one_rdm(self):
        r"""A 2-dimension array for CCSD one-particle density matrix in the MO
        representation.  d[p,q] = < a^\dagger_p a_q >
        """
        ccsd = self._pyscf_data.get('ccsd', None)
        if ccsd is None:
            return None

        mf = self._pyscf_data.get('scf', None)
        if isinstance(mf, scf.uhf.UHF):
            raise ValueError('Spin trace for UCCSD density matrix.')

        rdm1 = ccsd.make_rdm1()
        if isinstance(mf, scf.rohf.ROHF):
            rdm1 = rdm1[0] + rdm1[1]
        return rdm1.T

    @property
    def ccsd_two_rdm(self):
        r"""A 4-dimension array for CCSD two-particle density matrix in the MO
        representation.  D[p,q,r,s] = < a^\dagger_p a^\dagger_q a_r a_s >
        """
        ccsd = self._pyscf_data.get('ccsd', None)
        if ccsd is None:
            return None

        mf = self._pyscf_data.get('scf', None)
        if isinstance(mf, scf.uhf.UHF):
            raise ValueError('Spin trace for UCCSD density matrix.')

        rdm2 = ccsd.make_rdm2()
        if isinstance(mf, scf.rohf.ROHF):
            aa, ab, bb = rdm2
            rdm2 = aa + bb + ab + ab.transpose(2, 3, 0, 1)
        return rdm2.transpose(0, 2, 3, 1)

    @property
    def mp2_one_rdm(self):
        r"""A 2-dimension array for MP2 one-particle density matrix in the MO
        representation.  d[p,q] = < a^\dagger_p a_q >
        """
        mp2 = self._pyscf_data.get('mp2', None)
        if mp2 is None:
            return None

        mf = self._pyscf_data.get('scf', None)
        if isinstance(mf, scf.uhf.UHF):
            raise ValueError('Spin trace for UMP2 density matrix.')

        rdm1 = mp2.make_rdm1()
        if isinstance(mf, scf.rohf.ROHF):
            rdm1 = rdm1[0] + rdm1[1]
        return rdm1.T

    @property
    def mp2_two_rdm(self):
        r"""A 4-dimension array for MP2 two-particle density matrix in the MO
        representation.  D[p,q,r,s] = < a^\dagger_p a^\dagger_q a_r a_s >
        """
        mp2 = self._pyscf_data.get('mp2', None)
        if mp2 is None:
            return None

        mf = self._pyscf_data.get('scf', None)
        if isinstance(mf, scf.uhf.UHF):
            raise ValueError('Spin trace for UMP2 density matrix.')

        rdm2 = mp2.make_rdm2()
        if isinstance(mf, scf.rohf.ROHF):
            aa, ab, bb = rdm2
            rdm2 = aa + bb + ab + ab.transpose(2, 3, 0, 1)
        return rdm2.transpose(0, 2, 3, 1)

    @property
    def fci_one_rdm(self):
        r"""A 2-dimension array for FCI one-particle density matrix in the MO
        representation.  d[p,q] = < a^\dagger_p a_q >
        """
        if self._fci_one_rdm is None:
            fci = self._pyscf_data.get('fci', None)
            if fci is None:
                return None

            mf = self._pyscf_data.get('scf', None)
            if isinstance(mf, scf.uhf.UHF):
                raise ValueError('Spin trace for UHF-FCI density matrices.')

            norb = self.canonical_orbitals.shape[1]
            nelec = self.n_electrons
            self._fci_one_rdm = fci.make_rdm1(fci.ci, norb, nelec).T
        return self._fci_one_rdm

    @property
    def fci_two_rdm(self):
        r"""A 4-dimension array for FCI two-particle density matrix in the MO
        representation.  D[p,q,r,s] = < a^\dagger_p a^\dagger_q a_r a_s >
        """
        if self._fci_two_rdm is None:
            fci = self._pyscf_data.get('fci', None)
            if fci is None:
                return None

            mf = self._pyscf_data.get('scf', None)
            if isinstance(mf, scf.uhf.UHF):
                raise ValueError('Spin trace for UHF-FCI density matrix.')

            norb = self.canonical_orbitals.shape[1]
            nelec = self.n_electrons
            fci_rdm2 = fci.make_rdm2(fci.ci, norb, nelec)
            self._fci_two_rdm = fci_rdm2.transpose(0, 2, 3, 1)
        return self._fci_two_rdm

    @property
    def ccsd_single_amps(self):
        r"""A 2-dimension array t[a,i] for RCCSD single excitation amplitudes
        where a is virtual index and i is occupied index.
        """
        if self._ccsd_single_amps is None:
            ccsd = self._pyscf_data.get('ccsd', None)
            if ccsd is None:
                return None

            mf = self._pyscf_data.get('scf', None)
            if isinstance(mf, (scf.rohf.ROHF, scf.uhf.UHF)):
                #raise ValueError('UCCSD t1 amplitudes not available.')
                return None

            self._ccsd_single_amps = ccsd.t1.T
        return self._ccsd_single_amps

    @property
    def ccsd_double_amps(self):
        r"""A 4-dimension array t[a,b,i,j] for RCCSD double excitation amplitudes
        where a, b are virtual indices and i, j are occupied indices.
        """
        if self._ccsd_double_amps is None:
            ccsd = self._pyscf_data.get('ccsd', None)
            if ccsd is None:
                return None

            mf = self._pyscf_data.get('scf', None)
            if isinstance(mf, (scf.rohf.ROHF, scf.uhf.UHF)):
                #raise ValueError('UCCSD t2 amplitudes not available.')
                return None

            self._ccsd_double_amps = ccsd.t2.transpose(2, 3, 0, 1)
        return self._ccsd_double_amps



#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.

"""Tests for molecular_data."""
from __future__ import absolute_import

import numpy

from openfermionpyscf import prepare_pyscf_molecule
from openfermionpyscf import PyscfMolecularData
from pyscf import scf, mp, ci, cc, fci


geometry = [('H', (0., 0., 0.)), ('H', (0., 0., 0.7414))]
basis = '6-31g'
multiplicity = 1
charge = 0
molecule = PyscfMolecularData(geometry,
                              basis,
                              multiplicity,
                              charge)

mol = prepare_pyscf_molecule(molecule)
mol.verbose = 0
molecule._pyscf_data['mol'] = mol
molecule._pyscf_data['scf'] = mf = scf.RHF(mol).run()
molecule._pyscf_data['mp2'] = mp.MP2(mf).run()
molecule._pyscf_data['cisd'] = ci.CISD(mf).run()
molecule._pyscf_data['ccsd'] = cc.CCSD(mf).run()
molecule._pyscf_data['fci'] = fci.FCI(mf).run()


def test_accessing_rdm():
    mo = molecule.canonical_orbitals
    overlap = molecule.overlap_integrals
    h1 = molecule.one_body_integrals
    h2 = molecule.two_body_integrals
    mf = molecule._pyscf_data['scf']
    e_core = mf.energy_nuc()

    rdm1 = molecule.cisd_one_rdm
    rdm2 = molecule.cisd_two_rdm
    e_ref = molecule._pyscf_data['cisd'].e_tot
    e_tot = (numpy.einsum('pq,pq', h1, rdm1) +
             numpy.einsum('pqrs,pqrs', h2, rdm2) * .5 + e_core)
    numpy.testing.assert_almost_equal(e_tot, e_ref, 9)

    rdm1 = molecule.ccsd_one_rdm
    rdm2 = molecule.ccsd_two_rdm
    e_ref = molecule._pyscf_data['ccsd'].e_tot
    e_tot = (numpy.einsum('pq,pq', h1, rdm1) +
             numpy.einsum('pqrs,pqrs', h2, rdm2) * .5 + e_core)
    numpy.testing.assert_almost_equal(e_tot, e_ref, 7)

    rdm1 = molecule.fci_one_rdm
    rdm2 = molecule.fci_two_rdm
    #e_ref = molecule._pyscf_data['fci'].e_tot
    e_tot = (numpy.einsum('pq,pq', h1, rdm1) +
             numpy.einsum('pqrs,pqrs', h2, rdm2) * .5 + e_core)
    numpy.testing.assert_almost_equal(e_tot, -1.1516827321, 9)

    ccsd_t1 = molecule.ccsd_single_amps
    ccsd_t2 = molecule.ccsd_double_amps





#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.

import openfermion
import openfermionpyscf


def test_load_molecular_hamiltonian():
    geometry = [('Li', (0., 0., 0.)), ('H', (0., 0., 1.4))]

    lih_hamiltonian = openfermionpyscf.generate_molecular_hamiltonian(
            geometry, 'sto-3g', 1, 0, 2, 2)
    assert openfermion.count_qubits(lih_hamiltonian) == 4

    lih_hamiltonian = openfermionpyscf.generate_molecular_hamiltonian(
            geometry, 'sto-3g', 1, 0, 2, 3)
    assert openfermion.count_qubits(lih_hamiltonian) == 6

    lih_hamiltonian = openfermionpyscf.generate_molecular_hamiltonian(
            geometry, 'sto-3g', 1, 0, None, None)
    assert openfermion.count_qubits(lih_hamiltonian) == 12



#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.

"""Driver to initialize molecular object from pyscf program."""

from __future__ import absolute_import

from functools import reduce

import numpy
import pyscf

from openfermion import MolecularData
from openfermionpyscf import PyscfMolecularData


def prepare_pyscf_molecule(molecule):
    """
    This function creates and saves a pyscf input file.

    Args:
        molecule: An instance of the MolecularData class.

    Returns:
        pyscf_molecule: A pyscf molecule instance.
    """
    pyscf_molecule = pyscf.gto.Mole()
    pyscf_molecule.atom = molecule.geometry
    pyscf_molecule.basis = molecule.basis
    pyscf_molecule.spin = molecule.multiplicity - 1
    pyscf_molecule.charge = molecule.charge
    pyscf_molecule.symmetry = False
    pyscf_molecule.build()

    return pyscf_molecule


def compute_scf(pyscf_molecule):
    """
    Perform a Hartree-Fock calculation.

    Args:
        pyscf_molecule: A pyscf molecule instance.

    Returns:
        pyscf_scf: A PySCF "SCF" calculation object.
    """
    if pyscf_molecule.spin:
        pyscf_scf = pyscf.scf.ROHF(pyscf_molecule)
    else:
        pyscf_scf = pyscf.scf.RHF(pyscf_molecule)
    return pyscf_scf


def compute_integrals(pyscf_molecule, pyscf_scf):
    """
    Compute the 1-electron and 2-electron integrals.

    Args:
        pyscf_molecule: A pyscf molecule instance.
        pyscf_scf: A PySCF "SCF" calculation object.

    Returns:
        one_electron_integrals: An N by N array storing h_{pq}
        two_electron_integrals: An N by N by N by N array storing h_{pqrs}.
    """
    # Get one electrons integrals.
    n_orbitals = pyscf_scf.mo_coeff.shape[1]
    one_electron_compressed = reduce(numpy.dot, (pyscf_scf.mo_coeff.T,
                                                 pyscf_scf.get_hcore(),
                                                 pyscf_scf.mo_coeff))
    one_electron_integrals = one_electron_compressed.reshape(
        n_orbitals, n_orbitals).astype(float)

    # Get two electron integrals in compressed format.
    two_electron_compressed = pyscf.ao2mo.kernel(pyscf_molecule,
                                                 pyscf_scf.mo_coeff)

    two_electron_integrals = pyscf.ao2mo.restore(
        1, # no permutation symmetry
        two_electron_compressed, n_orbitals)
    # See PQRS convention in OpenFermion.hamiltonians._molecular_data
    # h[p,q,r,s] = (ps|qr)
    two_electron_integrals = numpy.asarray(
        two_electron_integrals.transpose(0, 2, 3, 1), order='C')

    # Return.
    return one_electron_integrals, two_electron_integrals


def run_pyscf(molecule,
              run_scf=True,
              run_mp2=False,
              run_cisd=False,
              run_ccsd=False,
              run_fci=False,
              verbose=False):
    """
    This function runs a pyscf calculation.

    Args:
        molecule: An instance of the MolecularData or PyscfMolecularData class.
        run_scf: Optional boolean to run SCF calculation.
        run_mp2: Optional boolean to run MP2 calculation.
        run_cisd: Optional boolean to run CISD calculation.
        run_ccsd: Optional boolean to run CCSD calculation.
        run_fci: Optional boolean to FCI calculation.
        verbose: Boolean whether to print calculation results to screen.

    Returns:
        molecule: The updated PyscfMolecularData object. Note the attributes
        of the input molecule are also updated in this function.
    """
    # Prepare pyscf molecule.
    pyscf_molecule = prepare_pyscf_molecule(molecule)
    molecule.n_orbitals = int(pyscf_molecule.nao_nr())
    molecule.n_qubits = 2 * molecule.n_orbitals
    molecule.nuclear_repulsion = float(pyscf_molecule.energy_nuc())

    # Run SCF.
    pyscf_scf = compute_scf(pyscf_molecule)
    pyscf_scf.verbose = 0
    pyscf_scf.run()
    molecule.hf_energy = float(pyscf_scf.e_tot)
    if verbose:
        print('Hartree-Fock energy for {} ({} electrons) is {}.'.format(
            molecule.name, molecule.n_electrons, molecule.hf_energy))

    # Hold pyscf data in molecule. They are required to compute density
    # matrices and other quantities.
    molecule._pyscf_data = pyscf_data = {}
    pyscf_data['mol'] = pyscf_molecule
    pyscf_data['scf'] = pyscf_scf

    # Populate fields.
    molecule.canonical_orbitals = pyscf_scf.mo_coeff.astype(float)
    molecule.orbital_energies = pyscf_scf.mo_energy.astype(float)

    # Get integrals.
    one_body_integrals, two_body_integrals = compute_integrals(
        pyscf_molecule, pyscf_scf)
    molecule.one_body_integrals = one_body_integrals
    molecule.two_body_integrals = two_body_integrals
    molecule.overlap_integrals = pyscf_scf.get_ovlp()

    # Run MP2.
    if run_mp2:
        if molecule.multiplicity != 1:
            print("WARNING: RO-MP2 is not available in PySCF.")
        else:
            pyscf_mp2 = pyscf.mp.MP2(pyscf_scf)
            pyscf_mp2.verbose = 0
            pyscf_mp2.run()
            # molecule.mp2_energy = pyscf_mp2.e_tot  # pyscf-1.4.4 or higher
            molecule.mp2_energy = pyscf_scf.e_tot + pyscf_mp2.e_corr
            pyscf_data['mp2'] = pyscf_mp2
            if verbose:
                print('MP2 energy for {} ({} electrons) is {}.'.format(
                    molecule.name, molecule.n_electrons, molecule.mp2_energy))

    # Run CISD.
    if run_cisd:
        pyscf_cisd = pyscf.ci.CISD(pyscf_scf)
        pyscf_cisd.verbose = 0
        pyscf_cisd.run()
        molecule.cisd_energy = pyscf_cisd.e_tot
        pyscf_data['cisd'] = pyscf_cisd
        if verbose:
            print('CISD energy for {} ({} electrons) is {}.'.format(
                molecule.name, molecule.n_electrons, molecule.cisd_energy))

    # Run CCSD.
    if run_ccsd:
        pyscf_ccsd = pyscf.cc.CCSD(pyscf_scf)
        pyscf_ccsd.verbose = 0
        pyscf_ccsd.run()
        molecule.ccsd_energy = pyscf_ccsd.e_tot
        pyscf_data['ccsd'] = pyscf_ccsd
        if verbose:
            print('CCSD energy for {} ({} electrons) is {}.'.format(
                molecule.name, molecule.n_electrons, molecule.ccsd_energy))

    # Run FCI.
    if run_fci:
        pyscf_fci = pyscf.fci.FCI(pyscf_molecule, pyscf_scf.mo_coeff)
        pyscf_fci.verbose = 0
        molecule.fci_energy = pyscf_fci.kernel()[0]
        pyscf_data['fci'] = pyscf_fci
        if verbose:
            print('FCI energy for {} ({} electrons) is {}.'.format(
                molecule.name, molecule.n_electrons, molecule.fci_energy))

    # Return updated molecule instance.
    pyscf_molecular_data = PyscfMolecularData.__new__(PyscfMolecularData)
    pyscf_molecular_data.__dict__.update(molecule.__dict__)
    pyscf_molecular_data.save()
    return pyscf_molecular_data


def generate_molecular_hamiltonian(
        geometry,
        basis,
        multiplicity,
        charge=0,
        n_active_electrons=None,
        n_active_orbitals=None):
    """Generate a molecular Hamiltonian with the given properties.

    Args:
        geometry: A list of tuples giving the coordinates of each atom.
            An example is [('H', (0, 0, 0)), ('H', (0, 0, 0.7414))].
            Distances in angstrom. Use atomic symbols to
            specify atoms.
        basis: A string giving the basis set. An example is 'cc-pvtz'.
            Only optional if loading from file.
        multiplicity: An integer giving the spin multiplicity.
        charge: An integer giving the charge.
        n_active_electrons: An optional integer specifying the number of
            electrons desired in the active space.
        n_active_orbitals: An optional integer specifying the number of
            spatial orbitals desired in the active space.

    Returns:
        The Hamiltonian as an InteractionOperator.
    """

    # Run electronic structure calculations
    molecule = run_pyscf(
            MolecularData(geometry, basis, multiplicity, charge)
    )

    # Freeze core orbitals and truncate to active space
    if n_active_electrons is None:
        n_core_orbitals = 0
        occupied_indices = None
    else:
        n_core_orbitals = (molecule.n_electrons - n_active_electrons) // 2
        occupied_indices = list(range(n_core_orbitals))

    if n_active_orbitals is None:
        active_indices = None
    else:
        active_indices = list(range(n_core_orbitals,
                                    n_core_orbitals + n_active_orbitals))

    return molecule.get_molecular_hamiltonian(
            occupied_indices=occupied_indices,
            active_indices=active_indices)



import io

from setuptools import setup, find_packages

# This reads the __version__ variable from openfermionpyscf/_version.py
exec(open('openfermionpyscf/_version.py').read())

# Readme file as long_description:
long_description = io.open('README.rst', encoding='utf-8').read()

# Read in requirements.txt
requirements = open('requirements.txt').readlines()
requirements = [r.strip() for r in requirements]

setup(
    name='openfermionpyscf',
    version=__version__,
    author='The OpenFermion Developers',
    author_email='help@openfermion.org',
    url='http://www.openfermion.org',
    description='A plugin allowing OpenFermion to interface with PySCF.',
    long_description=long_description,
    install_requires=requirements,
    license='Apache 2',
    packages=find_packages()
)



#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.

"""Tests many modules to call pyscf functions."""
from __future__ import absolute_import

from openfermion.hamiltonians import MolecularData
from openfermionpyscf import run_pyscf
from openfermionpyscf import PyscfMolecularData


geometry = [('H', (0., 0., 0.)), ('H', (0., 0., 0.7414))]
basis = '6-31g'
multiplicity = 1
charge = 0
molecule = MolecularData(geometry,
                         basis,
                         multiplicity,
                         charge)


def test_run_pyscf():
    new_mole = run_pyscf(molecule,
                         run_scf=True,
                         run_mp2=True,
                         run_cisd=True,
                         run_ccsd=True,
                         run_fci=True,
                         verbose=1)
    assert isinstance(new_mole, PyscfMolecularData)
